@@ -1,7 +1,7 @@
 # Colored terminal output for Python's logging module.
 #
 # Author: Peter Odding <peter@peterodding.com>
-# Last Change: July 15, 2017
+# Last Change: January 17, 2018
 # URL: https://coloredlogs.readthedocs.io
 
 """
@@ -54,26 +54,49 @@ Here we'll take a look at some examples of how you can customize
 .. contents::
    :local:
 
+About the defaults
+------------------
+
+Here's a screen shot of the default configuration for easy comparison with the
+screen shots of the following customizations (this is the same screen shot that
+is shown in the introduction):
+
+.. image:: images/defaults.png
+   :alt: Screen shot of colored logging with defaults.
+
+The screen shot above was taken from ``urxvt`` which doesn't support faint text
+colors, otherwise the color of green used for `debug` messages would have
+differed slightly from the color of green used for `spam` messages.
+
+Apart from the `faint` style of the `spam` level, the default configuration of
+`coloredlogs` sticks to the eight color palette defined by the original ANSI
+standard, in order to provide a somewhat consistent experience across terminals
+and terminal emulators.
+
+Available text styles and colors
+--------------------------------
+
+Of course you are free to customize the default configuration, in this case you
+can use any text style or color that you know is supported by your terminal.
+You can use the ``humanfriendly --demo`` command to try out the supported text
+styles and colors:
+
+.. image:: http://humanfriendly.readthedocs.io/en/latest/_images/ansi-demo.png
+   :alt: Screen shot of the 'humanfriendly --demo' command.
+
 Changing the log format
 -----------------------
 
 The simplest customization is to change the log format, for example:
 
-.. code-block:: sh
-
-   $ export COLOREDLOGS_LOG_FORMAT='[%(hostname)s] %(asctime)s - %(message)s'
-   $ coloredlogs --demo
-   [peter-macbook] 2015-10-22 23:42:28 - message with level 'debug'
-   [peter-macbook] 2015-10-22 23:42:29 - message with level 'verbose'
-   ...
+.. literalinclude:: examples/custom-log-format.txt
+   :language: sh
 
 Here's what that looks like in a terminal (I always work in terminals with a
 black background and white text):
 
 .. image:: images/custom-log-format.png
    :alt: Screen shot of colored logging with custom log format.
-   :align: center
-   :width: 80%
 
 Changing the date/time format
 -----------------------------
@@ -81,45 +104,36 @@ Changing the date/time format
 You can also change the date/time format, for example you can remove the date
 part and leave only the time:
 
-.. code-block:: sh
-
-   $ export COLOREDLOGS_LOG_FORMAT='%(asctime)s - %(message)s'
-   $ export COLOREDLOGS_DATE_FORMAT='%H:%M:%S'
-   $ coloredlogs --demo
-   23:45:22 - message with level 'debug'
-   23:45:23 - message with level 'verbose'
-   ...
+.. literalinclude:: examples/custom-datetime-format.txt
+   :language: sh
 
 Here's what it looks like in a terminal:
 
 .. image:: images/custom-datetime-format.png
    :alt: Screen shot of colored logging with custom date/time format.
-   :align: center
-   :width: 80%
 
 Changing the colors/styles
 --------------------------
 
 Finally you can customize the colors and text styles that are used:
 
-.. code-block:: sh
+.. literalinclude:: examples/custom-colors.txt
+   :language: sh
 
-   $ export COLOREDLOGS_LOG_FORMAT='%(asctime)s - %(message)s'
-   $ export COLOREDLOGS_DATE_FORMAT='%H:%M:%S'
-   $ export COLOREDLOGS_FIELD_STYLES='' # no styles
-   $ export COLOREDLOGS_LEVEL_STYLES='warning=yellow;error=red;critical=red,bold'
-   $ coloredlogs --demo
-   23:45:22 - message with level 'debug'
-   23:45:23 - message with level 'verbose'
-   ...
+Here's an explanation of the features used here:
 
-The difference isn't apparent from the above text but take a look at the
-following screen shot:
+- The numbers used in ``$COLOREDLOGS_LEVEL_STYLES`` demonstrate the use of 256
+  color mode (the numbers refer to the 256 color mode palette which is fixed).
+
+- The `success` level demonstrates the use of a text style (bold).
+
+- The `critical` level demonstrates the use of a background color (red).
+
+Of course none of this can be seen in the shell transcript quoted above, but
+take a look at the following screen shot:
 
 .. image:: images/custom-colors.png
    :alt: Screen shot of colored logging with custom colors.
-   :align: center
-   :width: 80%
 
 .. _notes about log levels:
 
@@ -199,7 +213,7 @@ WINDOWS = sys.platform.startswith('win')
 NEED_COLORAMA = WINDOWS
 
 # Semi-standard module versioning.
-__version__ = '7.1'
+__version__ = '9.0'
 
 DEFAULT_LOG_LEVEL = logging.INFO
 """The default log level for :mod:`coloredlogs` (:data:`logging.INFO`)."""
@@ -231,12 +245,13 @@ DEFAULT_FIELD_STYLES = dict(
 """Mapping of log format names to default font styles."""
 
 DEFAULT_LEVEL_STYLES = dict(
-    spam=dict(color='green'),
+    spam=dict(color='green', faint=True),
     debug=dict(color='green'),
     verbose=dict(color='blue'),
     info=dict(),
     notice=dict(color='magenta'),
     warning=dict(color='yellow'),
+    success=dict(color='green', bold=CAN_USE_BOLD_FONT),
     error=dict(color='red'),
     critical=dict(color='red', bold=CAN_USE_BOLD_FONT))
 """Mapping of log level names to default font styles."""
@@ -645,10 +660,28 @@ def parse_encoded_styles(text, normalize_key=None):
      'critical': {'bold': True, 'color': 'red'}}
     """
     parsed_styles = {}
-    for token in split(text, ';'):
-        name, _, styles = token.partition('=')
-        parsed_styles[name] = dict(('color', word) if word in ANSI_COLOR_CODES else
-                                   (word, True) for word in split(styles, ','))
+    for assignment in split(text, ';'):
+        name, _, styles = assignment.partition('=')
+        target = parsed_styles.setdefault(name, {})
+        for token in split(styles, ','):
+            # When this code was originally written, setting background colors
+            # wasn't supported yet, so there was no need to disambiguate
+            # between the text color and background color. This explains why
+            # a color name or number implies setting the text color (for
+            # backwards compatibility).
+            if token.isdigit():
+                target['color'] = int(token)
+            elif token in ANSI_COLOR_CODES:
+                target['color'] = token
+            elif '=' in token:
+                name, _, value = token.partition('=')
+                if name in ('color', 'background'):
+                    if value.isdigit():
+                        target[name] = int(value)
+                    elif value in ANSI_COLOR_CODES:
+                        target[name] = value
+            else:
+                target[token] = True
     return parsed_styles
 
 
@@ -813,8 +846,8 @@ class ColoredFormatter(logging.Formatter):
         Initialize a :class:`ColoredFormatter` object.
 
         :param fmt: A log format string (defaults to :data:`DEFAULT_LOG_FORMAT`).
-        :param datefmt: A date/time format string (defaults to
-                        :data:`DEFAULT_DATE_FORMAT`).
+        :param datefmt: A date/time format string (defaults to :data:`None`,
+                        but see the documentation of :func:`formatTime()`).
         :param level_styles: A dictionary with custom level styles
                              (defaults to :data:`DEFAULT_LEVEL_STYLES`).
         :param field_styles: A dictionary with custom field styles
@@ -829,8 +862,6 @@ class ColoredFormatter(logging.Formatter):
         # that Sphinx doesn't embed the default values in the generated
         # documentation (because the result is awkward to read).
         fmt = fmt or DEFAULT_LOG_FORMAT
-        datefmt = datefmt or DEFAULT_DATE_FORMAT
-        # Initialize instance attributes.
         self.level_styles = self.nn.normalize_keys(DEFAULT_LEVEL_STYLES if level_styles is None else level_styles)
         self.field_styles = self.nn.normalize_keys(DEFAULT_FIELD_STYLES if field_styles is None else field_styles)
         # Rewrite the format string to inject ANSI escape sequences and
@@ -924,6 +955,26 @@ class ColoredFormatter(logging.Formatter):
         # Delegate the remaining formatting to the base formatter.
         return logging.Formatter.format(self, record)
 
+    def formatTime(self, record, datefmt=None):
+        """
+        Format the date/time of a log record.
+
+        :param record: A :class:`~logging.LogRecord` object.
+        :param datefmt: A date/time format string (defaults to
+                        :data:`DEFAULT_DATE_FORMAT`).
+        :returns: The formatted date/time (a string).
+
+        This method overrides :func:`~logging.Formatter.formatTime()` to set
+        `datefmt` to :data:`DEFAULT_DATE_FORMAT` when the caller hasn't
+        specified a date format.
+        """
+        # The default value of the following argument is defined here so
+        # that Sphinx doesn't embed the default value in the generated
+        # documentation (because the result is awkward to read).
+        datefmt = datefmt or DEFAULT_DATE_FORMAT
+        # Delegate the remaining formatting to the base formatter.
+        return logging.Formatter.formatTime(self, record, datefmt)
+
 
 if sys.version_info[:2] <= (2, 6):
     # On Python 2.6 the logging.LogRecord class is an old-style class
